@@ -923,7 +923,7 @@ char* read_next_line(int script)
  **/
 void process_callbacks(void)
 {
-  int now = SDL_GetTicks();
+  int now = game_GetTicks();
   int i, k;
 
   for (i = 1; i < MAX_SCRIPTS; i++)
@@ -1492,8 +1492,7 @@ int var_figure(char* h, int script)
  */
 void int_prepare(char* line, int script)
 {
-  char hold[100];
-  strcpy(hold, line);
+  char* hold = strdup(line);
 
   char* name = NULL;
   char *temp = NULL;
@@ -1516,6 +1515,7 @@ void int_prepare(char* line, int script)
       strcpy(line, hold);
     }
   free(name);
+  free(hold);
 }
 
 
