@@ -1,7 +1,7 @@
 /**
  * Header for code common to FreeDink and FreeDinkedit
 
- * Copyright (C) 2005, 2007, 2008, 2009  Sylvain Beucler
+ * Copyright (C) 2005, 2007, 2008, 2009, 2010  Sylvain Beucler
 
  * This file is part of GNU FreeDink
 
@@ -135,8 +135,8 @@ extern void draw_status_all(void);
 extern void drawallhard( void);
 extern void duck_brain(int h);
 extern /*BOOL*/int init_mouse();
-extern void load_map_to(char* path, const int num, struct small_map* screen);
-extern void load_map(const int num);
+extern int load_map_to(char* path, const int num, struct small_map* screen);
+extern int load_map(const int num);
 extern int load_script(char filename[15], int sprite, /*bool*/int set_sprite);
 extern /*bool*/int locate(int script, char proc[20]);
 extern void process_callbacks(void);
@@ -171,14 +171,11 @@ extern struct show_bmp showb;
 extern int keep_mouse;
 extern int last_sprite_created;
 extern int mbase_count;
-extern int mbase_timing;
-extern int mcc;
 extern int mode;
 extern unsigned long mold;
 
 extern int *pupdate_status;
 extern struct small_map pam;
-extern int plane_process;
 extern int playl;
 extern int playx;
 extern int playy;
@@ -191,7 +188,6 @@ extern Uint32 lastTickCount;
 extern FPSmanager framerate_manager;
 extern /*bool*/int total_trigger;
 extern /*bool*/int trig_man;
-extern /*bool*/int turn_on_plane;
 
 /* extern HRESULT ddrval; */
 /* extern LPDIRECTDRAWPALETTE lpDDPal; /\* The primary surface palette *\/ */
@@ -209,8 +205,6 @@ extern int move_counter;
 extern int weapon_script;
 extern int magic_script;
 
-extern int process_count;
-
 /* Player */
 extern /*bool*/int inside_box(int x1, int y1, rect box);
 extern int walk_off_screen;
@@ -262,11 +256,20 @@ extern void figure_out(char* line);
 /* Metadata */
 extern int burn_revision;
 
+/*
+ * Game & editor
+ */
+/*bool*/int get_box (int h, rect * box_crap, rect * box_real);
+extern /*bool*/int dinkedit;
+extern int draw_map_tiny;
+extern int cur_map;
+extern struct hardness hmap;
+
+
 /*
  * Editor
  */
 
-/*bool*/int get_box (int h, rect * box_crap, rect * box_real);
 extern void check_sprite_status(int h);
 extern void add_hardness(int sprite, int num);
 extern void fill_whole_hard(void);
@@ -280,32 +283,6 @@ extern void save_info(void);
 extern int realhard(int tile);
 extern void save_hard(void);
 
-extern int draw_map_tiny;
-extern int cur_map, cur_tile;
-extern int map_vision;
-extern struct hardness hmap;
-extern int hard_tile;
-extern int m1x,m1y;
-extern int m2x, m2y;
-extern int m3x, m3y;
-extern int last_sprite_added;
-extern int sp_brain;
-extern int sp_speed;
-extern /*bool*/int sp_screenmatch;
-extern int in_huh;
-extern int in_master;
-extern int in_command;
-extern int in_max;
-extern int *in_int;
-extern char in_default[200];
-extern int in_onflag;
-extern char *in_string;
-extern char in_temp[200];
-extern int in_x, in_y;
-extern /*bool*/int in_enabled;
-extern int sp_mode;
-extern /*bool*/int dinkedit;
-
 extern /*bool*/int no_running_main;
 
 extern void fill_screen(int num);
